<!-- [![Build Status](https://travis-ci.com/GrupEstructuraElectronicaSimetria/symeess.svg?branch=master)](https://travis-ci.com/GrupEstructuraElectronicaSimetria/symeess) -->
<!-- [![Coverage Status](https://coveralls.io/repos/github/GrupEstructuraElectronicaSimetria/symeess/badge.svg?branch=master)](https://coveralls.io/github/GrupEstructuraElectronicaSimetria/symeess?branch=master) -->
<!-- [![PyPI version](https://badge.fury.io/py/symeess.svg)](https://badge.fury.io/py/symeess) -->
---------------------------------------------------------
README 0.1
---------------------------------------------------------
Package to calculate the molecular orbitals with the extended huckel method

---------------------------------------------------------
Installation instructions
---------------------------------------------------------
1. Requirements
    - Python 2.7/3.4 or higher
    - Numpy
    - PyYaml
    - Scipy
<!--     - tinker-tk -->

2. Download the source code and place it in the installation
directory

3. Run setup.py script to install
python setup.py install --user

---------------------------------------------------------
Contact info
---------------------------------------------------------
Electronic Structure & Symmetry group.
Department of Materials Science and Physical Chemistry.
Institut de Química Teòrica i Computacional (IQTC-UB)
University of Barcelona